Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
ErrInvalidJSON = errors.New("invalid json")
)
Functions ¶
Types ¶
type Store ¶
type Store interface {
io.Closer
// Get returns the value identified by the given URL.
Get(ctx context.Context, value Value) (string, error)
// Set updates the value identified by the given URL.
Set(ctx context.Context, value Value, updated string) error
// Delete destroys the value identified by the given URL.
Delete(ctx context.Context, value Value) error
}
Click to show internal directories.
Click to hide internal directories.